@@ -76,7 +76,7 @@ CrontabPrinter::~CrontabPrinter() {
 }
 
 bool CrontabPrinter::start() {
-	logDebug() << "Printing selection..." << endl;
+	logDebug() << "Printing selection...";
 
         if (d->printer == nullptr) {
             d->printer = new QPrinter();
@@ -95,7 +95,7 @@ bool CrontabPrinter::start() {
 	printDialog->setOptionTabs(QList<QWidget *>() << d->crontabWidget);
 	printDialog->setEnabledOptions(QAbstractPrintDialog::PrintToFile);
 	if (printDialog->exec() == QDialog::Rejected) {
-		logDebug() << "Printing canceled" << endl;
+		logDebug() << "Printing canceled";
 		delete printDialog;
 		return false;
 	}
@@ -265,7 +265,7 @@ void CrontabPrinter::finish() {
 }
 
 void CrontabPrinter::printPageNumber() {
-	logDebug() << "Printing page number..." << endl;
+	logDebug() << "Printing page number...";
 
 	d->painter->translate(0, - d->currentRowPosition);
 	d->printView->moveTo(QPoint(0, d->printView->height()) );
@@ -385,12 +385,12 @@ QList<int> CrontabPrinter::findColumnWidths(const QList<QStringList>& contents,
 
 	int columnWidthSum = 0;
 	foreach(int width, columnWidths) {
-		logDebug() << "Column : " << width << endl;
+		logDebug() << "Column : " << width;
 		columnWidthSum += width;
 	}
 
 	if (columnWidthSum >= pageWidth) {
-		logDebug() << "The printing could be out of the page" << endl;
+		logDebug() << "The printing could be out of the page";
 		return columnWidths;
 	}
 
